@@ -524,6 +524,7 @@ class PartCSVForm(forms.Form):
                             number_item = part_number
                             Part.objects.get(number_class=None, number_item=number_item, number_variation=None, organization=self.organization)
                             self.add_error(None, f"Part number {part_number} in row {row_count} already exists. Uploading of this part skipped.")
+                            continue
                         except Part.DoesNotExist:
                             pass
                 elif part_class:
@@ -662,6 +663,7 @@ class PartCSVForm(forms.Form):
                         manufacturer_part, created = ManufacturerPart.objects.get_or_create(part=part, manufacturer_part_number=mpn, manufacturer=mfg)
                         if part.primary_manufacturer_part is None and manufacturer_part is not None:
                             part.primary_manufacturer_part = manufacturer_part
+                            part.save()
 
                     self.successes.append("Part {0} on row {1} created.".format(part.full_part_number(), row_count))
                 else:
@@ -1049,9 +1051,11 @@ class BOMCSVForm(forms.Form):
             headers = [h.lower() for h in next(reader)]
 
             # Handle utf-8-sig encoding
-            if "\ufeff" in headers[0]:
+            if len(headers) > 0 and "\ufeff" in headers[0]:
                 reader = csv.reader(codecs.iterdecode(file, 'utf-8-sig'), dialect)
                 headers = [h.lower() for h in next(reader)]
+            elif len(headers) == 0:
+                self.warnings.append("No headers found in CSV file.")
 
             csv_headers = BOMIndentedCSVHeaders()
 
